@@ -39,8 +39,8 @@ _pkg_config = {
     'sip_config_args':  '',
     'sip_inc_dir':      '/usr/include/python2.5',
     'sip_mod_dir':      '/usr/lib/python2.5/site-packages',
-    'sip_version':      0x040a02,
-    'sip_version_str':  'snapshot-4.10.2-275fa5a54910',
+    'sip_version':      0x040a03,
+    'sip_version_str':  'snapshot-4.10.3-f760366cea3b',
     'universal':        ''
 }
 
@@ -121,6 +121,7 @@ _default_macros = {
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '-lpthread',
+    'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
     'LINK':                     'g++',
@@ -688,7 +689,8 @@ class Makefile:
                     "QtCore":       "LIBS_CORE",
                     "QtGui":        "LIBS_GUI",
                     "QtNetwork":    "LIBS_NETWORK",
-                    "QtOpenGL":     "LIBS_OPENGL"
+                    "QtOpenGL":     "LIBS_OPENGL",
+                    "QtWebKit":     "LIBS_WEBKIT"
                 }
 
                 # For Windows: the dependencies between Qt libraries.
@@ -808,7 +810,7 @@ class Makefile:
             libs.extend(self.optional_list("LIBS_OPENGL"))
 
         if self._qt or self._opengl:
-            if self.config.qt_version < 0x040000 or "QtGui" in self._qt:
+            if self.config.qt_version < 0x040000 or self._opengl or "QtGui" in self._qt:
                 incdir.extend(self.optional_list("INCDIR_X11"))
                 libdir.extend(self.optional_list("LIBDIR_X11"))
                 libs.extend(self.optional_list("LIBS_X11"))
@@ -2405,8 +2407,10 @@ def parse_build_macros(filename, names, overrides=None, properties=None):
         if line and line[0] != "#":
             assstart = line.find("+")
             if assstart > 0 and line[assstart + 1] == '=':
+                adding = True
                 assend = assstart + 1
             else:
+                adding = False
                 assstart = line.find("=")
                 assend = assstart
 
@@ -2417,6 +2421,11 @@ def parse_build_macros(filename, names, overrides=None, properties=None):
                 # Remove the escapes for any quotes.
                 rhs = rhs.replace(r'\"', '"').replace(r"\'", "'")
 
+                if adding and rhs != "":
+                    orig_rhs = raw.get(lhs)
+                    if orig_rhs is not None:
+                        rhs = orig_rhs + " " + rhs
+
                 raw[lhs] = rhs
 
         line = f.readline()
